==> haskell-html-conduit-1.3.2.1-106-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-html-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 html-conduit
version:              1.3.2.1
visibility:           public
id:                   html-conduit-1.3.2.1-IxPVD5qzPKpEQEGnbG9NQe
key:                  html-conduit-1.3.2.1-IxPVD5qzPKpEQEGnbG9NQe
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/xml
synopsis:             Parse HTML documents using xml-conduit datatypes.
description:
    This package uses tagstream-conduit for its parser. It automatically balances mismatched tags, so that there shouldn'\''t be any parse failures. It does not handle a full HTML document rendering, such as adding missing html and head tags. Note that, since version 1.3.1, it uses an inlined copy of tagstream-conduit with entity decoding bugfixes applied.

category:             Web, Text, Conduit
abi:                  0c50ae0b3a8dd2bed75b892aae699134
exposed:              True
exposed-modules:      Text.HTML.DOM
hidden-modules:       Text.HTML.TagStream
import-dirs:          /usr/lib/ghc-8.10.2/site-local/html-conduit-1.3.2.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/html-conduit-1.3.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/html-conduit-1.3.2.1
hs-libraries:         HShtml-conduit-1.3.2.1-IxPVD5qzPKpEQEGnbG9NQe
depends:
    attoparsec-0.13.2.4-5M99CjVqPJb6HJ808kFFFu base-4.14.1.0
    bytestring-0.10.10.0 conduit-1.3.2.1-HNABJBEXsQzJcaoQ6IRgWj
    conduit-extra-1.3.5-8VoBBG5H35tK85Hh6y9Z1I containers-0.6.2.1
    resourcet-1.2.4.2-4RFnQe9pXdr8Q71XjQPYNv text-1.2.3.2
    transformers-0.5.6.2 xml-conduit-1.9.0.0-IxGVz8WrM7IIJH6nXc5Fmz
    xml-types-0.3.8-1FskkqwabAiJVamcx9xCWD

haddock-interfaces:
    /usr/share/doc/haskell-html-conduit/html/html-conduit.haddock

haddock-html:         /usr/share/doc/haskell-html-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-html-conduit-1.3.2.1-120-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-html-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 html-conduit
version:              1.3.2.1
visibility:           public
id:                   html-conduit-1.3.2.1-2P1Rl4E5Gnd5gW8byvvakr
key:                  html-conduit-1.3.2.1-2P1Rl4E5Gnd5gW8byvvakr
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/xml
synopsis:             Parse HTML documents using xml-conduit datatypes.
description:
    This package uses tagstream-conduit for its parser. It automatically balances mismatched tags, so that there shouldn'\''t be any parse failures. It does not handle a full HTML document rendering, such as adding missing html and head tags. Note that, since version 1.3.1, it uses an inlined copy of tagstream-conduit with entity decoding bugfixes applied.

category:             Web, Text, Conduit
abi:                  dc3b37704d7170ad6605e1aa3f9518d5
exposed:              True
exposed-modules:      Text.HTML.DOM
hidden-modules:       Text.HTML.TagStream
import-dirs:          /usr/lib/ghc-8.10.2/site-local/html-conduit-1.3.2.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/html-conduit-1.3.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/html-conduit-1.3.2.1
hs-libraries:         HShtml-conduit-1.3.2.1-2P1Rl4E5Gnd5gW8byvvakr
depends:
    attoparsec-0.13.2.4-6s9PGXpTa8d5vs3WhgDbsJ base-4.14.1.0
    bytestring-0.10.10.0 conduit-1.3.3-43QepFrPR4DvW5qHGbMEo
    conduit-extra-1.3.5-ExFQYTVHU1P9hRhEjo6NeC containers-0.6.2.1
    resourcet-1.2.4.2-3ZadZMbpZwrIcStk9cdzU2 text-1.2.3.2
    transformers-0.5.6.2 xml-conduit-1.9.0.0-FXxBsYadGphCirgWxY3M3I
    xml-types-0.3.8-1FskkqwabAiJVamcx9xCWD

haddock-interfaces:
    /usr/share/doc/haskell-html-conduit/html/html-conduit.haddock

haddock-html:         /usr/share/doc/haskell-html-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
